# ex_bloc

ExBloc provide simple way to organize bloc middleware and dispatch events.

## Usage

# Import

```dart
final store = ExStore.instance;
```

# Simple state

```dart
class TestState {
  final bool afterInitial;

  const TestState({this.afterInitial});
  factory TestState.initial() {
    return const TestState(afterInitial: false);
  }
}
```

# Simple bloc

`ExBloc` does not contain business logic.

`ServiceModel` should contain third party dependencies or `EmptyServiceModel` if there are no third party dependencies.

```dart
class TestBloc extends ExBloc<TestEvent, TestState, EmptyServiceModel> {
  TestBloc(EmptyServiceModel sm) : super(sm);

  @override
  TestState get initialState => TestState.initial();
}
```

# Event

`ExEvent` provide business logic and payload

`ExStore` provide ability to dispatch other events or get other states. 

```dart
class TestEvent extends ExEvent<TestState, EmptyServiceModel> {
  @override
  Stream<TestState> call(
      ExStore store, TestState state, EmptyServiceModel sm) async* {
    yield TestState(afterInitial: true);
  }
}
```

# Dispatch events

```dart
store.dispatch(TestEvent());
```
or
```dart
TestEvent().dispatch();
```
